@@ -6,6 +6,7 @@ from django.conf import global_settings
 abspath = lambda *p: os.path.abspath(os.path.join(*p))
 
 DEBUG = True
+TEMPLATE_DEBUG = DEBUG
 PROJECTOR_HG_PUSH_SSL = False
 
 PROJECT_ROOT = abspath(os.path.dirname(__file__))
@@ -61,9 +62,11 @@ INSTALLED_APPS = (
     'richtemplates',
     'projector',
     'vcs.web.simplevcs',
+    'sss',
 
     'example_project',
 )
+ADMINBROWSE_MEDIA_URL = '/media/adminbrowse/'
 
 MIDDLEWARE_CLASSES = (
     'django.middleware.common.CommonMiddleware',
@@ -121,6 +124,7 @@ PROJECTOR_PROJECTS_ROOT_DIR = abspath(
 PROJECTOR_BANNED_PROJECT_NAMES = ('barfoo',)
 PROJECTOR_SEND_MAIL_ASYNCHRONOUSELY = True
 PROJECTOR_CREATE_PROJECT_ASYNCHRONOUSLY = True
+PROJECTOR_FORK_EXTERNAL_ENABLED = True
 
 # =============== #
 # DJALOG SETTINGS #
