@@ -118,8 +118,7 @@ class ProjectBaseForm(forms.ModelForm):
 class ProjectCreateForm(ProjectBaseForm):
     vcs_alias = forms.ChoiceField(choices=VCS_BACKENDS_CHOICES,
         label=_('Version Control Backend'),
-        initial=get_config_value('DEFAULT_VCS_BACKEND'),
-        widget=forms.HiddenInput) # Hidden until more backends are supported
+        initial=get_config_value('DEFAULT_VCS_BACKEND'))
 
     def save(self, commit=True):
         instance = super(ProjectCreateForm, self).save(commit=False)
@@ -164,6 +163,8 @@ class TaskForm(LimitingModelForm):
         widget=forms.DateInput(attrs={'class': 'datepicker'}))
     watch_changes = forms.BooleanField(False, label=_('Watch for changes'),
         initial=True)
+    description = RestructuredTextAreaField(max_length=3000,
+        label=_('Description'))
 
     class Meta:
         model = Task
@@ -201,8 +202,6 @@ class TaskForm(LimitingModelForm):
 class TaskEditForm(TaskForm):
     deadline = forms.DateField(required=False, label=_("Deadline"),
         widget=forms.DateInput(attrs={'class': 'datepicker'}))
-    description = RestructuredTextAreaField(max_length=3000,
-        label=_('Description'))
     comment = RestructuredTextAreaField(max_length=3000,
         label=_('Comment'), widget=forms.Textarea, required=False)
 
@@ -372,6 +371,8 @@ class TeamDeleteForm(forms.Form):
 
 
 class MilestoneForm(forms.ModelForm, PerProjectUniqueNameMixin):
+    created_at = forms.DateField(required=False, label=_("Start date"),
+        widget=forms.DateInput(attrs={'class': 'datepicker'}))
     deadline = forms.DateField(required=False, label=_("Deadline"),
         widget=forms.DateInput(attrs={'class': 'datepicker'}))
 
