@@ -15,13 +15,15 @@ from django.contrib.sites.models import Site
 from django.core.exceptions import ValidationError, PermissionDenied,\
     ImproperlyConfigured
 from django.core.mail import send_mail
+from django.core.urlresolvers import reverse
 from django.db import models
 from django.db.models import Q
 from django.db.models.query import QuerySet
 from django.template.defaultfilters import slugify
 from django.template.loader import render_to_string
-from django.utils.translation import ugettext_lazy as _
 from django.utils.datastructures import SortedDict
+from django.utils.translation import ugettext_lazy as _
+from django.utils.timesince import timesince
 
 from guardian.shortcuts import assign, get_perms, get_perms_for_model
 
@@ -308,6 +310,14 @@ class Project(AL_Node, Watchable):
             'member_username': username,
         })
 
+    @models.permalink
+    def get_members_delete_url(self, username):
+        return ('projector_project_member_delete', (), {
+            'username': self.author.username,
+            'project_slug': self.slug,
+            'member_username': username,
+        })
+
     @models.permalink
     def get_teams_url(self):
         return ('projector_project_teams', (), {
@@ -351,6 +361,13 @@ class Project(AL_Node, Watchable):
             'project_slug': self.slug,
         })
 
+    @models.permalink
+    def get_milestone_gantt_url(self):
+        return ('projector_project_milestones_gantt', (), {
+            'username': self.author.username,
+            'project_slug': self.slug,
+        })
+
     @models.permalink
     def get_milestone_add_url(self):
         return ('projector_project_milestone_add', (), {
@@ -407,6 +424,44 @@ class Project(AL_Node, Watchable):
             'project_slug': self.slug,
         })
 
+    def get_clone_url(self):
+        if self.repository is None:
+            return None
+        if self.repository.alias == 'hg':
+            return self.get_absolute_url()
+        elif self.repository.alias == 'git':
+            return reverse('projector-project-git', kwargs={
+                'username': self.author.username,
+                'project_slug': self.slug,
+            }).rstrip('/')
+        return None
+
+    def get_repo_url(self):
+        """
+        Returns full url of the project (with domain based on
+        django sites framework).
+        """
+        current_site = Site.objects.get_current()
+        # FIXME: What should we do with hardcoded schemas?
+        if settings.DEBUG:
+            prefix = 'http://'
+        else:
+            prefix = 'https://'
+
+        suffix = self.get_clone_url() or self.get_absolute_url()
+        return ''.join((prefix, current_site.domain, suffix))
+
+    def get_clone_cmd(self):
+        """
+        Returns client command to run in order to clone this repository.
+        """
+        url = self.get_repo_url()
+        if self.repository.alias == 'hg':
+            return 'hg clone %s' % url
+        elif self.repository.alias == 'git':
+            return 'git clone %s' % url.rstrip('/')
+        return None
+
     def is_pending(self):
         return self.state != State.ERROR and self.state < State.READY
 
@@ -471,19 +526,6 @@ class Project(AL_Node, Watchable):
         repo_path = abspath(self._get_homedir(), alias)
         return repo_path
 
-    def get_repo_url(self):
-        """
-        Returns full url of the project (with domain based on
-        django sites framework).
-        """
-        current_site = Site.objects.get_current()
-        # FIXME: What should we do with hardcoded schemas?
-        if settings.DEBUG:
-            prefix = 'http://'
-        else:
-            prefix = 'https://'
-        return ''.join((prefix, current_site.domain, self.get_absolute_url()))
-
     def add_timeline_entry(self, action, author):
         """
         Initially wanted to implement as models.signal handler -
@@ -853,6 +895,64 @@ class Project(AL_Node, Watchable):
         """
         return self.parent is not None or self.fork_url
 
+    def get_actions(self):
+        """
+        Returns activity stream for this projcet.
+        """
+        #return Project.objects.get_actions(self)
+        return self.actions.all()
+
+    def create_action(self, verb, **kwargs):
+        return Action.objects.create(project=self, verb=verb, **kwargs)
+
+
+class ActionManager(models.Manager):
+    def create(self, **kwargs):
+        action_object = kwargs.pop('action_object', None)
+        if action_object is not None:
+            kwargs['action_object_content_type'] = \
+                ContentType.objects.get_for_model(action_object)
+            kwargs['action_object_pk'] = action_object.pk
+        return super(ActionManager, self).create(**kwargs)
+
+
+class Action(models.Model):
+    project = models.ForeignKey(Project, verbose_name=_('Project'),
+        related_name='actions')
+    author = models.ForeignKey(User, null=True, blank=True,
+        verbose_name=_('User'))
+    verb = models.CharField(_('verb'), max_length=128)
+    description = models.TextField(_('description'), null=True, blank=True)
+    created_at = models.DateTimeField(_('created at'),
+        default=datetime.datetime.now)
+    is_public = models.BooleanField(_('is public'), default=True)
+
+    # Optional related object
+    action_object_pk = models.CharField(max_length=255, null=True, blank=True)
+    action_object_content_type = models.ForeignKey(ContentType, null=True,
+        blank=True, verbose_name=_('content type'))
+    action_object = generic.GenericForeignKey('action_object_content_type',
+        'action_object_pk')
+
+    objects = ActionManager()
+
+    class Meta:
+        verbose_name = _('action')
+        verbose_name_plural = _('actions')
+        ordering = ['-created_at']
+        get_latest_by = 'created_at'
+
+    def __unicode__(self):
+        if self.action_object:
+            return u'%s %s %s %s ago' % (self.author, self.verb,
+                self.action_object, self.timesince())
+        return u'%s %s %s %s ago' % (self.author, self.verb, self.project,
+            self.timesince())
+
+    def timesince(self, now=None):
+        return timesince(self.created_at, now)
+
+
 class Config(models.Model):
     """
     This model stores configuration on "per project" basis.
@@ -1023,7 +1123,8 @@ class Milestone(models.Model):
         always_update=True, unique_with='project')
     description = models.TextField()
     author = models.ForeignKey(User, verbose_name=_('author'))
-    created_at = models.DateTimeField(_('created at'), auto_now_add=True)
+    created_at = models.DateTimeField(_('created at'),
+        default=datetime.datetime.now)
     deadline = models.DateField(_('deadline'), default=datetime.date.today() +
         datetime.timedelta(days=10))
             #projector_settings.get_config_value('MILESTONE_DEADLINE_DELTA')))
@@ -1088,11 +1189,14 @@ class Milestone(models.Model):
 class TimelineEntry(models.Model):
     project = models.ForeignKey(Project, verbose_name=_('project'),
         editable=False)
-    created_at = models.DateTimeField(_('created at'), auto_now_add=True)
-    user = models.ForeignKey(User, verbose_name=_('user'), null=True,
+    created_at = models.DateTimeField(_('created at'), db_index=True,
+        default=datetime.datetime.now)
+    author = models.ForeignKey(User, verbose_name=_('author'), null=True,
         blank=True, editable=False)
     action = models.CharField(_('action'), max_length=256,
-        help_text=_('Short note on activity, i.e.: commit message'))
+        help_text=_('Short note on activity, i.e.: "created", "joined" etc.'))
+    description = models.TextField(_('description'), null=True, blank=True,
+        help_text=_('May be for example a commit messages from single push'))
 
     class Meta:
         ordering = ('-created_at',)
@@ -1544,4 +1648,23 @@ def get_user_from_string(value):
 
 from projector.listeners import start_listening
 start_listening()
+from projector.actions import actions_start_listening
+actions_start_listening()
+
+
+class Commit(models.Model):
+    id = models.CharField(max_length=255)
+    project = models.ForeignKey(Project)
+    repo = models.ForeignKey(Repository)
+
+    class Meta:
+        abstract = True
+
+    @models.permalink
+    def get_absolute_url(self):
+        return {
+            'username': self.project.author.username,
+            'project_slug': self.project.slug,
+            'revision': self.id,
+        }
 
