@@ -1,10 +1,12 @@
 from version import *
+from test_activity import *
 from test_component import *
 from test_concurrency import *
 from test_controllers import *
 from test_emails import *
 from test_fork import *
 from test_helpers import *
+from test_members import *
 from test_milestone import *
 from test_permissions import *
 from test_settings import *
