@@ -31,13 +31,14 @@ class RepositoryView(ProjectView):
         if not self.project.repository_id:
             messages.info(self.request, _("Project has no repository"))
             response = redirect(self.project)
-        if not self.project._get_repo_path():
+        elif not self.project._get_repo_path() or \
+                self.project.repository is None:
             msg = _("There is something wrong with project's repository")
             messages.error(self.request, msg)
             response = redirect(self.project)
-        if not self.project.repository or not self.project.repository.revisions:
+        elif not self.project.repository.revisions:
             messages.info(self.request, _("Repository has no changesets yet"))
-            response = redirect(self.project)
+            return RepositoryQuickstart(self.request, *self.args, **self.kwargs)
         return response
 
     def get_error_response(self):
@@ -134,7 +135,8 @@ class RepositoryFileRaw(RepositoryView):
     def response(self, request, username, project_slug, revision, rel_repo_url):
         if self.has_errors:
             return self.get_error_response()
-        node = self.project.repository.request(rel_repo_url, revision)
+        changeset = self.project.repository.get_changeset(revision)
+        node = changeset.get_node(rel_repo_url)
         response = HttpResponse(node.content, mimetype=node.mimetype)
         response['Content-Disposition'] = 'attachment; filename=%s' % node.name
         return response
@@ -216,3 +218,17 @@ class RepositoryChangesetDetail(RepositoryView):
         return diff_changeset(self.request, **diff_info)
 
 
+class RepositoryQuickstart(RepositoryView):
+    """
+    Shows quickstart help for the project's repository.
+
+    **View attributes**
+
+    * ``template_name``: ``'projector/project/repository/quickstart.html'``.
+    """
+
+    template_name = 'projector/project/repository/quickstart.html'
+
+    def response(self, request, username, project_slug):
+        return self.context
+
